<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Lafka_Shipping_Areas {
	/**
	 * The single instance of the class.
	 */
	protected static $_instance = null;

	/**
	 * Constructor.
	 */
	protected function __construct() {
		$this->includes();
		$this->init();
	}

	/**
	 * Instance.
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}

		return self::$_instance;
	}

	/**
	 * Cloning is forbidden.
	 */
	public function __clone() {
		wc_doing_it_wrong( __FUNCTION__, __( 'Cloning is forbidden.', 'lafka-plugin' ), '1.0.0' );
	}

	/**
	 * Unserializing instances of this class is forbidden.
	 */
	public function __wakeup() {
		_doing_it_wrong( __FUNCTION__, __( 'Foul!', 'lafka-plugin' ), '1.0.0' );
	}

	/**
	 * Function for loading dependencies.
	 */
	private function includes() {
		$options = get_option( 'lafka_shipping_areas_branches' );

		require_once dirname( __FILE__ ) . '/includes/class-lafka-shipping-areas-method.php';
		require_once dirname( __FILE__ ) . '/includes/class-lafka-api.php';
		require_once dirname( __FILE__ ) . '/shortcodes/shortcode-lafka-shipping-areas.php';
		if ( ! empty( $options['enable_branch_selection_modal'] ) ) {
			require_once dirname( __FILE__ ) . '/includes/class-lafka-branch-locations.php';
		}

		if ( is_admin() ) {
			require_once dirname( __FILE__ ) . '/includes/class-lafka-shipping-areas-admin.php';
			require_once dirname( __FILE__ ) . '/includes/class-lafka-branch-locations-admin.php';
			if ( function_exists( 'vc_lean_map' ) ) {
				vc_lean_map( 'lafka_shipping_areas', null, dirname( __FILE__ ) . '/shortcodes/shortcode-lafka-shipping-areas-to-vc.php' );
			}
		}
	}

	private function init() {
		// Register Lafka Shipping Areas post type
		add_action( 'init', array( $this, 'register_lafka_shipping_areas' ) );
		add_action( 'init', array( $this, 'register_branch_locations_taxonomy' ) );

		// Scripts and styles
		add_action( 'wp_enqueue_scripts', array( $this, 'enqueue_scripts' ) );

		// Shipping Method Register Hooks
		add_action( 'woocommerce_shipping_init', 'lafka_shipping_areas_method_init' );
		add_filter( 'woocommerce_shipping_methods', array( $this, 'add_lafka_shipping_areas_method' ) );
		// Apply shipping areas restrictions
		add_action( 'woocommerce_after_get_rates_for_package', array( $this, 'apply_shipping_area_restrictions' ) );
		// Inject delivery address into ajax update_order_review response
		add_action( 'woocommerce_update_order_review_fragments', array( $this, 'update_order_review_fragments' ) );
		// Show picked location in order
		add_action( 'woocommerce_admin_order_data_after_billing_address', array( $this, 'show_checkout_fields_admin_order_meta' ), 10, 1 );
		// Add map to check out
		add_action( 'woocommerce_review_order_before_payment', array( $this, 'add_map_to_checkout' ) );
		// Validate "mandatory to pick address"
		add_action( 'woocommerce_checkout_process', array( $this, 'validate_checkout_field_process' ) );

		$options = get_option( 'lafka_shipping_areas_general' );
		if ( ! empty( $options['lowest_cost_shipping'] ) ) {
			add_action( 'woocommerce_after_shipping_rate', array( $this, 'add_rates_cost_as_hidden' ), 10, 2 );
		}
		if ( ! empty( $options['hide_shipping_cost_at_cart'] ) ) {
			add_filter( 'woocommerce_cart_ready_to_calc_shipping', array( $this, 'disable_shipping_calculation_on_cart' ), 999 );
		}
		$advanced_options = get_option( 'lafka_shipping_areas_advanced' );
		if ( ! empty( $advanced_options['deactivate_post_code'] ) ) {
			add_filter( 'woocommerce_default_address_fields', array( $this, 'disable_postcode_validation' ) );
		}

		$datetime_options = get_option( 'lafka_shipping_areas_datetime' );
		if ( ! empty( $datetime_options['enable_datetime_option'] ) ) {
			// Add Delivery/Pickup Time to the checkout page
			add_action( 'woocommerce_checkout_before_customer_details', array( __CLASS__, 'show_datetime_fields_in_checkout' ) );
			// Retrieve time slots for date
			if ( class_exists( 'Lafka_Order_Hours' ) ) {
				add_action( 'wp_ajax_time_slots_for_date', array( __CLASS__, 'retrieve_time_slots_for_date' ) );
				add_action( 'wp_ajax_nopriv_time_slots_for_date', array( __CLASS__, 'retrieve_time_slots_for_date' ) );
			}
			// Save datetime to order
			add_action( 'woocommerce_checkout_update_order_meta', array( $this, 'checkout_datetime_update_order_meta' ), 10, 1 );
			// Show datetime in order list and make it sortable
			add_filter( 'manage_shop_order_posts_columns', array( __CLASS__, 'add_datetime_to_orders_list' ), 20 );
			add_action( 'manage_shop_order_posts_custom_column', array( __CLASS__, 'add_datetime_content_to_orders_list' ) );
			add_action( 'manage_edit-shop_order_sortable_columns', array( __CLASS__, 'add_datetime_to_sortable_columns' ) );
		}

		// Output order type, time for delivery/pickup, branch, picked delivery location in all places
		add_filter( 'woocommerce_get_order_item_totals', array( __CLASS__, 'output_custom_fields_in_thank_you_page' ), 10, 3 );
		// Clear shipping rates cache in order to use dynamic shipping calculations
		add_action( 'woocommerce_checkout_update_order_review', array( __CLASS__, 'clear_wc_shipping_rates_cache' ) );
	}

	public function register_lafka_shipping_areas() {
		$labels = array(
			'name'               => __( 'Lafka Shipping Areas', 'lafka-plugin' ),
			'singular_name'      => __( 'Lafka Shipping Area', 'lafka-plugin' ),
			'name_admin_bar'     => __( 'Lafka Shipping Area', 'lafka-plugin' ),
			'add_new'            => __( 'Add New', 'lafka-plugin' ),
			'add_new_item'       => __( 'Add New Lafka Shipping Area', 'lafka-plugin' ),
			'new_item'           => __( 'New Lafka Shipping Area', 'lafka-plugin' ),
			'edit_item'          => __( 'Edit Lafka Shipping Area', 'lafka-plugin' ),
			'view_item'          => __( 'View Lafka Shipping Area', 'lafka-plugin' ),
			'all_items'          => __( 'Lafka Shipping Areas', 'lafka-plugin' ),
			'search_items'       => __( 'Search Lafka Shipping Areas', 'lafka-plugin' ),
			'parent_item_colon'  => '',
			'not_found'          => __( 'Nothing found.', 'lafka-plugin' ),
			'not_found_in_trash' => __( 'Nothing found in Trash.', 'lafka-plugin' ),
		);

		$args = array(
			'labels'             => $labels,
			'public'             => true,
			'publicly_queryable' => false,
			'show_ui'            => true,
			'show_in_menu'       => 'woocommerce',
			'query_var'          => true,
			'rewrite'            => false,
			'capability_type'    => 'product',
			'hierarchical'       => false,
			'menu_position'      => null,
			'supports'           => array( 'title', 'author' ),
		);

		register_post_type( 'lafka_shipping_areas', $args );

		add_shortcode( 'lafka_shipping_areas', 'lafka_shipping_areas_shortcode' );
	}

	public function register_branch_locations_taxonomy() {
		$labels = array(
			'name'          => esc_html__( 'Lafka Branch Locations', 'lafka-plugin' ),
			'singular_name' => esc_html__( 'Branch Location', 'lafka-plugin' ),
			'search_items'  => esc_html__( 'Search Branch Location', 'lafka-plugin' ),
			'all_items'     => esc_html__( 'All Branch Location', 'lafka-plugin' ),
			'edit_item'     => esc_html__( 'Edit Branch Location', 'lafka-plugin' ),
			'update_item'   => esc_html__( 'Update Branch Location', 'lafka-plugin' ),
			'add_new_item'  => esc_html__( 'Add New Branch Location', 'lafka-plugin' ),
			'back_to_items' => esc_html__( 'Go to Branch Locations', 'lafka-plugin' ),
			'not_found'     => esc_html__( 'No Branch Locations found', 'lafka-plugin' ),
			'menu_name'     => esc_html__( 'Lafka Branch Locations', 'lafka-plugin' ),
		);
		$args   = array(
			'publicly_queryable' => false,
			'hierarchical'       => false,
			'labels'             => $labels,
			'show_ui'            => true,
			'show_admin_column'  => true,
			'show_in_menu'       => true,
			'show_in_nav_menus'  => false,
			'show_tagcloud'      => false
		);

		register_taxonomy( 'lafka_branch_location', 'product', $args );
	}

	public function add_lafka_shipping_areas_method( $methods ) {
		$methods['lafka_shipping_areas_method'] = 'Lafka_Shipping_Areas_Method';

		return $methods;
	}

	public function get_all_delivery_areas(): array {
		$args = array(
			'numberposts' => 100,
			'post_type'   => 'lafka_shipping_areas',
			'post_status' => 'publish',
			'orderby'     => 'title',
		);

		return get_posts( $args );
	}

	public function enqueue_scripts() {
		wp_enqueue_style( 'lafka-shipping-areas-front', plugins_url( 'assets/css/frontend/lafka-shipping-areas-front.css', __FILE__ ), array(), '1.0' );

		if ( is_cart() || is_checkout() ) {
			wp_enqueue_script( 'lafka-shipping-areas-handle-shipping', plugins_url( 'assets/js/frontend/lafka-shipping-areas-handle-shipping.min.js', __FILE__ ), array(
				'jquery',
				'google-maps',
				'jquery-blockui'
			), '1.0', true );

			$options                 = get_option( 'lafka_shipping_areas_general' );
			$options_advanced        = get_option( 'lafka_shipping_areas_advanced' );
			$branch_location_session = WC()->session->get( 'lafka_branch_location' );

			// Init a properties variable
			wp_add_inline_script( 'lafka-shipping-areas-handle-shipping', '
				const lafka_shipping_properties = {};
				const lafka_no_shipping_methods_string = "' . esc_html__( 'There are no shipping options available. Please ensure that your address has been entered correctly, or contact us if you need any help.', 'lafka-plugin' ) . '";
				const lafka_debug_mode = ' . ( empty( $options_advanced['debug_mode'] ) ? 'false' : 'true' ) . ';
				const lafka_lowest_cost_shipping = ' . ( empty( $options['lowest_cost_shipping'] ) ? 'false' : 'true' ) . ';
				const lafka_store_address = "' . Lafka_Shipping_Areas::get_store_address() . '";
				const lafka_set_store_location = "' . ( empty( $options_advanced['set_store_location'] ) ? 'geo_woo_store' : $options_advanced['set_store_location'] ) . '";
				const lafka_store_map_location = "' . ( empty( $options_advanced['store_map_location'] ) ? '' : $options_advanced['store_map_location'] ) . '";
				const lafka_order_type = "' . ( empty( $branch_location_session['order_type'] ) ? '' : $branch_location_session['order_type'] ) . '";
				', 'before' );
		}

		$datetime_options = get_option( 'lafka_shipping_areas_datetime' );
		if ( is_checkout() && ! empty( $datetime_options['enable_datetime_option'] ) ) {
			$days_ahead                    = $datetime_options['days_ahead'] ?? 30;
			$timeslot_duration             = $datetime_options['timeslot_duration'] ?? 60;
			$timeslots_without_order_hours = array();
			if ( class_exists( 'Lafka_Order_Hours' ) && ! empty( Lafka_Order_Hours::$lafka_order_hours_options['lafka_order_hours_schedule'] ) ) {
				$enabled_dates = Lafka_Order_Hours::get_enabled_dates_for_days_ahead( $days_ahead, $timeslot_duration );
			} else {
				$enabled_dates                 = self::get_all_days_ahead( $days_ahead );
				$timeslots_without_order_hours = self::get_all_timeslots_static( $timeslot_duration );
			}
			wp_enqueue_script( 'flatpickr', plugins_url( '../../assets/js/flatpickr/flatpickr.min.js', __FILE__ ), array( 'jquery' ), '4.6.9', true );
			wp_enqueue_style( 'flatpickr', plugins_url( '../../assets/js/flatpickr/flatpickr.min.css', __FILE__ ), array(), '4.6.9' );
			wp_enqueue_script( 'lafka-shipping-datetime', plugins_url( 'assets/js/frontend/lafka-shipping-datetime.min.js', __FILE__ ), array( 'jquery', 'select2', 'flatpickr' ), '1.0', true );
			wp_localize_script( 'lafka-shipping-datetime', 'lafka_datetime_options', array(
				'is_order_hours_enabled'        => class_exists( 'Lafka_Order_Hours' ),
				'timeslots_without_order_hours' => $timeslots_without_order_hours,
				'days_ahead'                    => $days_ahead,
				'enabled_dates'                 => $enabled_dates,
				'ajax_url'                      => admin_url( 'admin-ajax.php' ),
				'nonce'                         => wp_create_nonce( 'time_slots_for_date' ),
				'select_time_label'             => esc_html__( 'Select time...', 'lafka-plugin' ),
				'datetime_mandatory'            => ! empty( $datetime_options['datetime_mandatory'] )
			) );
		}
	}

	public function apply_shipping_area_restrictions( $package ) {
		unset( $package['rates'] );
	}

	public function update_order_review_fragments( $fragments ) {
		if ( WC()->customer->has_shipping_address() ) {
			$delivery_address = WC()->customer->get_shipping();
		} else {
			$delivery_address = WC()->customer->get_billing();
		}
		$all_countries                     = WC()->countries->get_countries();
		$delivery_address['country_label'] = $all_countries[ $delivery_address['country'] ] ?? '';
		$fragments['delivery_address']     = $delivery_address;

		return $fragments;
	}

	public function checkout_datetime_update_order_meta( $order_id ) {
		$datetime_options = get_option( 'lafka_shipping_areas_datetime' );

		if ( ! empty( $_POST['lafka_picked_delivery_geocoded'] ) ) {
			update_post_meta( $order_id, 'lafka_picked_delivery_geocoded', sanitize_text_field( $_POST['lafka_picked_delivery_geocoded'] ) );
		}
		if ( ! empty( $_POST['lafka_checkout_date'] ) ) {
			update_post_meta( $order_id, 'lafka_checkout_date', sanitize_text_field( $_POST['lafka_checkout_date'] ) );
		} elseif ( ! empty( $datetime_options['datetime_mandatory'] ) ) {
			wc_add_notice( esc_html__( 'Please enter Delivery/Pickup time.', 'lafka-plugin' ), 'error' );
		}
		if ( ! empty( $_POST['lafka_checkout_timeslot'] ) ) {
			update_post_meta( $order_id, 'lafka_checkout_timeslot', sanitize_text_field( $_POST['lafka_checkout_timeslot'] ) );
		} elseif ( ! empty( $datetime_options['datetime_mandatory'] ) ) {
			wc_add_notice( esc_html__( 'Please enter Delivery/Pickup time.', 'lafka-plugin' ), 'error' );
		}
	}

	public static function add_datetime_to_orders_list( $columns ): array {
		$columns['lafka_datetime_complete'] = esc_html__( 'Delivery/Pickup Time', 'lafka-plugin' );

		return $columns;
	}

	public static function add_datetime_content_to_orders_list( $column ) {
		global $post;
		if ( $column === 'lafka_datetime_complete' ) {
			$date     = get_post_meta( $post->ID, 'lafka_checkout_date', true );
			$timeslot = get_post_meta( $post->ID, 'lafka_checkout_timeslot', true );

			if ( ! empty( $date ) ) {
				echo '<span class="lafka-delivery-date">' . esc_html( $date ) . '</span>';
			}
			if ( ! empty( $timeslot ) ) {
				echo '<span class="lafka-delivery-timeslot">' . esc_html( $timeslot ) . '</span>';
			}
		}
	}

	public static function add_datetime_to_sortable_columns(): array {
		$columns['lafka_datetime_complete'] = 'lafka_checkout_date';

		return $columns;
	}

	public static function output_custom_fields_in_thank_you_page( $total_rows, $order, $tax_display ) {
		$order_type       = get_post_meta( $order->get_id(), 'lafka_order_type', true );
		$order_type_label = esc_html__( 'Delivery', 'lafka-plugin' );
		if ( ! empty( $order_type ) ) {
			if ( $order_type === 'pickup' ) {
				$order_type_label = esc_html__( 'Pickup', 'lafka-plugin' );
			}
			$total_rows['lafka_order_type'] = array(
				'label' => esc_html__( 'Order Type:', 'lafka-plugin' ),
				'value' => $order_type_label,
			);
		}

		$lafka_checkout_date = get_post_meta( $order->get_id(), 'lafka_checkout_date', true );
		if ( ! empty( $lafka_checkout_date ) ) {
			$total_rows['lafka_checkout_date'] = array(
				'label' => esc_html( $order_type_label ) . ' ' . esc_html__( 'Date:', 'lafka-plugin' ),
				'value' => DateTime::createFromFormat( 'Y-m-d', $lafka_checkout_date )->format( get_option( 'date_format' ) )
			);
		}

		$lafka_checkout_timeslot = get_post_meta( $order->get_id(), 'lafka_checkout_timeslot', true );
		if ( ! empty( $lafka_checkout_timeslot ) ) {
			$total_rows['lafka_checkout_timeslot'] = array(
				'label' => esc_html( $order_type_label ) . ' ' . esc_html__( 'Time:', 'lafka-plugin' ),
				'value' => esc_html( $lafka_checkout_timeslot )
			);
		}

		$lafka_selected_branch_id = get_post_meta( $order->get_id(), 'lafka_selected_branch_id', true );
		if ( ! empty( $lafka_selected_branch_id ) ) {
			$branch_location = get_term( $lafka_selected_branch_id, 'lafka_branch_location' );
			if ( ! empty( $branch_location ) ) {
				$total_rows['lafka_selected_branch_id'] = array(
					'label' => esc_html__( 'Branch:', 'lafka-plugin' ),
					'value' => esc_html( $branch_location->name )
				);
			}
		}

		$lafka_picked_delivery_geocoded = get_post_meta( $order->get_id(), 'lafka_picked_delivery_geocoded', true );
		if ( ! empty( $lafka_picked_delivery_geocoded ) && is_string( $lafka_picked_delivery_geocoded ) ) {
			$location = json_decode( $lafka_picked_delivery_geocoded );
			if ( $location !== null && isset( $location->lat ) ) {
				$total_rows['lafka_picked_delivery_geocoded'] = array(
					'label' => esc_html__( 'Picked Delivery Location:', 'lafka-plugin' ),
					'value' => self::get_delivery_location_link( $location )
				);
			}
		}

		return $total_rows;
	}

	public static function clear_wc_shipping_rates_cache() {
		$packages = WC()->cart->get_shipping_packages();
		foreach ( $packages as $package_key => $package ) {
			WC()->session->set( 'shipping_for_package_' . $package_key, false ); // Or true
		}
	}

	public function show_checkout_fields_admin_order_meta( $order ) {
		echo '<div class="address">';

		$order_type       = get_post_meta( $order->get_id(), 'lafka_order_type', true );
		$order_type_label = esc_html__( 'Delivery', 'lafka-plugin' );
		if ( ! empty( $order_type ) ) {
			if ( $order_type === 'pickup' ) {
				$order_type_label = esc_html__( 'Pickup', 'lafka-plugin' );
			}
			?>
            <p>
                <strong><?php esc_html_e( 'Order Type', 'lafka-plugin' ); ?>:</strong>
				<?php echo esc_html( $order_type_label ); ?>
            </p>
			<?php
		}

		$lafka_checkout_date = get_post_meta( $order->get_id(), 'lafka_checkout_date', true );
		if ( ! empty( $lafka_checkout_date ) ) {
			?>
            <p>
                <strong><?php echo esc_html( $order_type_label ) . ' ' . esc_html__( 'Date', 'lafka-plugin' ); ?>:</strong>
				<?php echo esc_html( DateTime::createFromFormat( 'Y-m-d', $lafka_checkout_date )->format( get_option( 'date_format' ) ) ); ?>
            </p>
			<?php
		}

		$lafka_checkout_timeslot = get_post_meta( $order->get_id(), 'lafka_checkout_timeslot', true );
		if ( ! empty( $lafka_checkout_timeslot ) ) {
			?>
            <p>
                <strong><?php echo esc_html( $order_type_label ) . ' ' . esc_html__( 'Time', 'lafka-plugin' ); ?>:</strong>
				<?php echo esc_html( $lafka_checkout_timeslot ); ?>
            </p>
			<?php
		}

		$lafka_selected_branch_id = get_post_meta( $order->get_id(), 'lafka_selected_branch_id', true );
		if ( ! empty( $lafka_selected_branch_id ) ) {
			$branch_location = get_term( $lafka_selected_branch_id, 'lafka_branch_location' );
			if ( ! empty( $branch_location ) ) {
				?>
                <p>
                    <strong><?php esc_html_e( 'Branch', 'lafka-plugin' ); ?>:</strong>
					<?php echo esc_html( $branch_location->name ); ?>
                </p>
				<?php
			}
		}

		$meta = get_post_meta( $order->get_id(), 'lafka_picked_delivery_geocoded', true );
		if ( ! empty( $meta ) && is_string( $meta ) ) {
			$location = json_decode( $meta );
			if ( $location !== null && isset( $location->lat ) ) {
				?>
                <p>
                    <strong><?php esc_html_e( 'Picked Delivery Location', 'lafka-plugin' ); ?>:</strong>
					<?php echo self::get_delivery_location_link( $location ); ?>
                </p>
				<?php
			}
		}
		echo '</div>';
	}

	public function add_map_to_checkout() {
		if ( ! is_checkout() || WC()->cart->needs_shipping() === false ) {
			return;
		}

		$options = get_option( 'lafka_shipping_areas_general' );
		if ( empty( $options['pick_delivery_address'] ) ) {
			return;
		}

		if ( empty( $options['mandatory_pickup_delivery'] ) ) {
			$title = esc_html__( 'Address not found! You can pinpoint Your Location on the map.', 'lafka-plugin' );
		} else {
			$title = esc_html__( 'Address not found! Pinpoint Your Location on the map to Continue', 'lafka-plugin' );
		}

		echo '<div id="lafka_pick_delivery_address_field" class="shop_table">';
		echo '<h3 class="lafka-address-not-found">' . esc_html( $title ) . '</h3>';
		echo '<h3 class="lafka-address-marked">' . esc_html__( 'Pinpoint your location on the map if it\'s not accurately marked.', 'lafka-plugin' ) . '</h3>';

		woocommerce_form_field( 'lafka_picked_delivery_geocoded', array(
			'type'  => 'text',
			'class' => array(
				'hidden'
			),
			'label' => esc_html__( 'Please Precise Your Location', 'lafka-plugin' )
		) );

		echo '<div id="lafka-pick-delivery-address-content">';
		echo '<div id="lafka-pick-delivery-address-checkout-map">';
		echo '</div></div></div>';

		wp_add_inline_script( 'lafka-shipping-areas-handle-shipping', 'lafka_checkout_map_properties = ' . json_encode( array(
				'pick_delivery_address_option' => $options['pick_delivery_address'],
			) ), 'before' );
	}

	public function validate_checkout_field_process() {
		$options = get_option( 'lafka_shipping_areas_general' );

		if ( ! empty( $options['pick_delivery_address'] ) && ! empty( $options['mandatory_pickup_delivery'] ) && isset( $_POST['lafka_picked_delivery_geocoded'] ) && empty( $_POST['lafka_picked_delivery_geocoded'] ) ) {
			wc_add_notice( esc_html__( 'Please precise your address on the map.', 'lafka-plugin' ), 'error' );
		}
	}

	public function add_rates_cost_as_hidden( $method, $index ) {
		printf( '<input type="hidden" name="shipping_method[%1$d]_lafka_cost" data-index="%1$d" id="shipping_method_%1$d_%2$s_lafka_cost" value="%3$s" class="lafka-shipping-cost %4$s" />', $index, esc_attr( sanitize_title( $method->id ) ), esc_attr( $method->get_cost() ), sanitize_html_class( $method->get_method_id() ) ); // WPCS: XSS ok.
	}

	public function disable_shipping_calculation_on_cart( $show_shipping ) {
		if ( is_cart() ) {
			return false;
		}

		return $show_shipping;
	}

	public function disable_postcode_validation( $fields ): array {
		$fields['postcode']['required'] = false;

		return $fields;
	}

	public static function show_datetime_fields_in_checkout() {
		$order_type_label = esc_html__( 'Delivery', 'lafka-plugin' );
		if ( ! empty( WC()->session ) ) {
			$branch_location_session = WC()->session->get( 'lafka_branch_location' );
			if ( ! empty( $branch_location_session ) ) {
				$order_type = $branch_location_session['order_type'];
				if ( $order_type === 'pickup' ) {
					$order_type_label = esc_html__( 'Pickup', 'lafka-plugin' );
				}
			}
		}
		$datetime_options = get_option( 'lafka_shipping_areas_datetime' );
		$days_ahead       = $datetime_options['days_ahead'] ?? 30;
		?>
        <div class="lafka-checkout-datetime-container">
            <div class="lafka-checkout-datetime-trigger">
                <a href="javascript:" class="lafka-delivery-time-toggle" title="<?php esc_html_e( 'Toggle Time Pickers', 'lafka-plugin' ); ?>">
					<?php echo esc_html__( 'Specify', 'lafka-plugin' ) . ' '; ?><?php echo esc_html( $order_type_label ); ?><?php echo ' ' . esc_html__( 'Time', 'lafka-plugin' ); ?>
					<?php if ( empty( $datetime_options['datetime_mandatory'] ) ): ?>
						<?php esc_html_e( '(optional)', 'lafka-plugin' ); ?>
					<?php else: ?>
                        <abbr class="required" title="<?php echo esc_html__( 'required', 'lafka-plugin' ); ?>">*</abbr>
					<?php endif; ?>
                </a>
            </div>
            <div class="lafka-checkout-datetime-fields<?php if ( empty( $datetime_options['datetime_mandatory'] ) ): ?> hidden<?php endif; ?>">
                <input name="lafka_checkout_date" id="lafka_checkout_date" <?php if ( $days_ahead < 1 ): ?>class="hidden"<?php endif; ?> type="text"
                       placeholder="<?php esc_html_e( 'Select Date', 'lafka-plugin' ); ?>..">
                <select name="lafka_checkout_timeslot" id="lafka_checkout_timeslot">
					<?php if ( empty( $datetime_options['datetime_mandatory'] ) ): ?>
                        <option></option>
					<?php endif; ?>
                </select>
				<?php if ( $days_ahead > 0 && empty( $datetime_options['datetime_mandatory'] ) ): ?>
                    <a href="javascript:" class="lafka-datetime-clear"
                       title="<?php esc_html_e( 'Clear', 'lafka-plugin' ); ?> <?php echo esc_html( $order_type_label ); ?> <?php esc_html_e( 'Time Entries', 'lafka-plugin' ); ?>"><?php echo esc_html__( 'Clear', 'lafka-plugin' ); ?></a>
				<?php endif; ?>
            </div>
        </div>
		<?php
	}

	public static function retrieve_time_slots_for_date() {
		check_ajax_referer( 'time_slots_for_date' );

		$datetime_options  = get_option( 'lafka_shipping_areas_datetime' );
		$timeslot_duration = $datetime_options['timeslot_duration'] ?? 60;

		$date      = DateTime::createFromFormat( 'Y-m-d', sanitize_text_field( $_POST['date'] ), Lafka_Order_Hours:: get_timezone() );
		$timeslots = Lafka_Order_Hours::get_timeslots_for_date( $date, $timeslot_duration );
		wp_send_json_success( $timeslots );
	}

	private static function get_all_days_ahead( $days_ahead ): array {
		$current_time = new DateTime( 'now' );
		$interval     = DateInterval::createFromDateString( '1 day' );
		$days         = array( $current_time->format( 'Y-m-d' ) );

		for ( $i = 1; $i <= $days_ahead; $i ++ ) {
			$days[] = $current_time->add( $interval )->format( 'Y-m-d' );
		}

		return $days;
	}

	private static function get_all_timeslots_static( $timeslot_duration ): array {
		$timeslots = array();

		$curr_time = new DateTime();
		$time      = clone $curr_time->setTime( 0, 0 );
		$interval  = DateInterval::createFromDateString( $timeslot_duration . ' minutes' );
		while ( $curr_time->format( 'Y-m-d' ) === $time->format( 'Y-m-d' ) ) {
			$start = $time->format( 'H:i' );
			$end   = $time->add( $interval )->format( 'H:i' );
			if ( $time->format( 'Y-m-d' ) !== $curr_time->format( 'Y-m-d' ) ) {
				$end = '24:00';
			}

			$timeslots[] = array(
				'id'   => $start . ' - ' . $end,
				'text' => $start . ' - ' . $end
			);
		}

		return $timeslots;
	}

	private static function get_delivery_location_link( $location ): string {
		$lat  = $location->lat;
		$long = $location->lng;

		return '<a target="_blank" href="https://www.google.com/maps/search/?api=1&query=' . $lat . ',' . $long . '" >' . esc_html__( 'Open delivery location with Google Maps', 'lafka-plugin' ) . '</a>';
	}

	public static function get_store_address(): string {
		$store_address     = get_option( 'woocommerce_store_address', '' );
		$store_address_2   = get_option( 'woocommerce_store_address_2', '' );
		$store_city        = get_option( 'woocommerce_store_city', '' );
		$store_postcode    = get_option( 'woocommerce_store_postcode', '' );
		$store_raw_country = get_option( 'woocommerce_default_country', '' );
		$split_country     = explode( ":", $store_raw_country );
		// Country and state
		$store_country = $split_country[0];
		// Convert country code to full name if available
		if ( isset( WC()->countries->countries[ $store_country ] ) ) {
			$store_country = WC()->countries->countries[ $store_country ];
		}
		$store_state = $split_country[1] ?? '';

		return $store_address . ' ' . $store_address_2 . ' ' . $store_postcode . ' ' . $store_city . ' ' . $store_state . ' ' . $store_country;;
	}

	public static function get_all_legit_branch_locations(): array {
		$args = array(
			'taxonomy'   => 'lafka_branch_location',
			'hide_empty' => false,
			'fields'     => 'id=>name',
			'meta_query' => array(
				array(
					'key'     => 'lafka_branch_address',
					'value'   => '',
					'compare' => '!='
				),
				array(
					'key'     => 'lafka_branch_address_geocoded',
					'value'   => '',
					'compare' => '!='
				)
			)
		);

		$all_legit_branch_locations = get_terms( $args );

		if ( is_array( $all_legit_branch_locations ) ) {
			return $all_legit_branch_locations;
		} else {
			return array();
		}
	}
}

/**
 * Function for delaying initialization of the extension until after WooCommerce is loaded.
 */
function lafka_shipping_areas_initialize() {

	// This is also a great place to check for the existence of the WooCommerce class
	if ( ! class_exists( 'WooCommerce' ) ) {
		return;
	}

	$GLOBALS['lafka_shipping_areas'] = Lafka_Shipping_Areas::instance();
}

add_action( 'plugins_loaded', 'lafka_shipping_areas_initialize', 10 );