<?php
defined( 'ABSPATH' ) || exit;

class Lafka_Branch_Locations_Admin {
	/**
	 * Setup Admin class.
	 */
	public static function init() {
		add_action( 'admin_enqueue_scripts', array( __CLASS__, 'admin_enqueue_scripts' ) );
		add_action( 'lafka_branch_location_add_form_fields', array( __CLASS__, 'add_branch_location_fields' ), 11, 2 );
		add_action( 'lafka_branch_location_edit_form_fields', array( __CLASS__, 'edit_branch_location_fields' ), 11, 2 );
		add_action( 'created_lafka_branch_location', array( __CLASS__, 'edit_branch_location' ), 10, 4 );
		add_action( 'edit_lafka_branch_location', array( __CLASS__, 'edit_branch_location' ), 10, 4 );
		// Show Address field in the taxonomy terms list screens in admin
		add_filter( 'manage_edit-lafka_branch_location_columns', array( __CLASS__, 'add_address_column_to_location_branches' ), 2 );
		add_filter( 'manage_lafka_branch_location_custom_column', array( __CLASS__, 'add_address_column_content_to_location_branches' ), 10, 3 );
		// Show Branch location field in the orders list screens in admin
		add_filter( 'manage_shop_order_posts_columns', array( __CLASS__, 'add_columns_to_orders_list' ), 20 );
		add_action( 'manage_shop_order_posts_custom_column', array( __CLASS__, 'add_columns_content_to_orders_list' ) );
		add_action( 'manage_edit-shop_order_sortable_columns', array( __CLASS__, 'add_columns_to_sortable_columns' ) );
		add_action( 'pre_get_posts', array( __CLASS__, 'orders_list_define_sort_and_search_queries_for_custom_fields' ) );
		add_action( 'restrict_manage_posts', array( __CLASS__, 'add_fields_to_orders_list_filter' ), 10, 2 );
	}

	public static function admin_enqueue_scripts() {
		wp_enqueue_media();
		wp_enqueue_script( 'lafka-branch-locations-admin', plugins_url( '../assets/js/backend/lafka-branch-locations-admin.min.js', __FILE__ ), array( 'jquery', 'google-maps', 'select2' ), '1.0', true );
		$options_branches = get_option( 'lafka_shipping_areas_branches' );
		wp_localize_script( 'lafka-branch-locations-admin', 'lafka_branch_location_properties', array(
			'geocode_label'         => esc_html__( 'Geocode', 'lafka-plugin' ),
			'clear_label'           => esc_html__( 'Clear', 'lafka-plugin' ),
			'geocode_error'         => esc_html__( 'Geocode was not successful for the following reason', 'lafka-plugin' ),
			'geocode_approximate'   => esc_html__( 'The entered address leads to approximate result. Please precise the address or pick from the map.', 'lafka-plugin' ),
			'choose_image_label'    => esc_html__( "Choose an image", "lafka-plugin" ),
			'use_image_label'       => esc_html__( "Use image", "lafka-plugin" ),
			'placeholder_image_src' => esc_url( wc_placeholder_img_src() ),
			'products_by_branches'  => ! empty( $options_branches['products_by_branches'] )
		) );
	}

	public static function add_branch_location_fields() {
		global /** @var Lafka_Shipping_Areas $lafka_shipping_areas */
		$lafka_shipping_areas;

		$delivery_areas = array();
		foreach ( $lafka_shipping_areas->get_all_delivery_areas() as $area ) {
			$delivery_areas[ $area->ID ] = get_the_title( $area->ID );
		}
		?>
        <div>
            <label for="lafka_branch_delivery_time"><?php esc_html_e( 'Estimated Delivery/Prep Time', 'lafka-plugin' ); ?></label>
            <input name="lafka_branch_delivery_time" id="lafka_branch_delivery_time" type="text"/>
            <p><?php esc_html_e( 'Enter the average delivery/prep time for this branch. Will be displayed in the branch info box.', 'lafka-plugin' ); ?></p>
        </div>
        <div class="form-field">
            <label><?php echo esc_html__( 'Branch Location Image', 'lafka-plugin' ); ?></label>
            <div id="lafka_branch_location_img" style="float: left; margin-right: 10px;"><img
                        src="<?php echo esc_url( wc_placeholder_img_src() ); ?>" width="60px" height="60px"/></div>
            <div style="line-height: 60px;">
                <input type="hidden" id="lafka_branch_location_img_id" name="lafka_branch_location_img_id"/>
                <button type="button"
                        class="lafka_branch_location_img_upload_image_button button"><?php echo esc_html__( 'Upload/Add image', 'lafka-plugin' ); ?></button>
                <button type="button"
                        class="lafka_branch_location_img_remove_image_button button"><?php echo esc_html__( 'Remove image', 'lafka-plugin' ); ?></button>
            </div>
            <div class="clear"></div>
            <p><?php esc_html_e( 'The image will be shown on the popup for selecting the branch.', 'lafka-plugin' ); ?></p>
        </div>
        <div>
            <label for="lafka_branch_shipping_areas"><?php esc_html_e( 'Shipping Areas', 'lafka-plugin' ); ?></label>
            <select multiple="multiple" class="wc-enhanced-select" name="lafka_branch_shipping_areas[]" id="lafka_branch_shipping_areas"
                    data-placeholder="<?php esc_attr_e( 'Choose Shipping Areas&hellip;', 'lafka-plugin' ); ?>" aria-label="<?php esc_attr_e( 'Shipping Areas', 'lafka-plugin' ); ?>">
				<?php foreach ( $delivery_areas as $option_key => $option_value ) : ?>
                    <option value="<?php echo esc_attr( $option_key ); ?>"><?php echo esc_html( $option_value ); ?></option>
				<?php endforeach; ?>
            </select>
            <p><?php esc_html_e( 'Choose Lafka Shipping Areas covered by this branch.', 'lafka-plugin' ); ?></p>
        </div>
        <div>
            <label for="lafka_branch_distance_restriction"><?php esc_html_e( 'Radius Restriction', 'lafka-plugin' ); ?></label>
            <input name="lafka_branch_distance_restriction" id="lafka_branch_distance_restriction" type="number"/>
            <p><?php esc_html_e( 'Suitable for radius based delivery restrictions. This option is only used for the initial check (popup) of the delivery availability based on the user address.', 'lafka-plugin' ); ?></p>
        </div>
        <div>
            <label for="lafka_branch_distance_unit"><?php esc_html_e( 'Distance Unit', 'lafka-plugin' ); ?></label>
            <select class="select wc-enhanced-select" name="lafka_branch_distance_unit" id="lafka_branch_distance_unit" style="">
                <option value="metric"><?php esc_html_e( 'Metric (km)', 'lafka-plugin' ); ?></option>
                <option value="imperial"><?php esc_html_e( 'Imperial (miles)', 'lafka-plugin' ); ?></option>
            </select>
        </div>
        <div class="form-field form-required lafka_branch_address-wrap">
            <label for="lafka_branch_address"><?php esc_html_e( 'Address', 'lafka-plugin' ); ?></label>
            <input name="lafka_branch_address" id="lafka_branch_address" placeholder="<?php esc_html_e( 'Enter a location', 'lafka-plugin' ); ?>" type="text"/>
            <input name="lafka_branch_address_geocoded" id="lafka_branch_address_geocoded" type="hidden"/>
            <p class="description">
				<?php esc_html_e( 'The full address for the branch to calculate distance shipping and apply radius restrictions.', 'lafka-plugin' ); ?>
				<?php esc_html_e( 'Note: Branch Location will be active only if it is properly geocoded.', 'lafka-plugin' ); ?><br>
                <span class="lafka-branch-address-instructions">
                    <strong><?php esc_html_e( 'Instructions', 'lafka-plugin' ); ?></strong>: <?php esc_html_e( 'Enter an address in the textbox and geocode or click on the map to set the location.', 'lafka-plugin' ); ?>
                </span>
            </p>
        </div>
        <div id="lafka_geocode_branch_location_map"></div>
		<?php
	}

	public static function edit_branch_location_fields( $term ) {
		$branch_delivery_time  = get_term_meta( $term->term_id, 'lafka_branch_delivery_time', true );
		$branch_image_id       = get_term_meta( $term->term_id, 'lafka_branch_location_img_id', true );
		$address               = get_term_meta( $term->term_id, 'lafka_branch_address', true );
		$address_geocoded      = get_term_meta( $term->term_id, 'lafka_branch_address_geocoded', true );
		$branch_shipping_areas = json_decode( get_term_meta( $term->term_id, 'lafka_branch_shipping_areas', true ) );
		$distance_restriction  = get_term_meta( $term->term_id, 'lafka_branch_distance_restriction', true );
		$distance_unit         = get_term_meta( $term->term_id, 'lafka_branch_distance_unit', true );

		global /** @var Lafka_Shipping_Areas $lafka_shipping_areas */
		$lafka_shipping_areas;

		$delivery_areas = array();
		foreach ( $lafka_shipping_areas->get_all_delivery_areas() as $area ) {
			$delivery_areas[ $area->ID ] = get_the_title( $area->ID );
		}

		if ( empty( $address_geocoded ) ) {
			$address = '';
		}

		if ( $branch_image_id ) {
			$branch_image_src = wp_get_attachment_thumb_url( $branch_image_id );
		} else {
			$branch_image_src = wc_placeholder_img_src();
		}
		?>
        <tr class="form-field">
            <th scope="row">
                <label for="lafka_branch_delivery_time"><?php esc_html_e( 'Estimated Delivery/Prep Time', 'lafka-plugin' ); ?></label>
            </th>
            <td>
                <input name="lafka_branch_delivery_time" id="lafka_branch_delivery_time" type="text" value="<?php esc_attr_e( $branch_delivery_time ); ?>"/>
                <p><?php esc_html_e( 'Enter the average delivery/prep time for this branch. Will be displayed in the branch info box.', 'lafka-plugin' ); ?></p>
            </td>
        </tr>
        <tr class="form-field">
            <th scope="row" valign="top"><label><?php echo esc_html__( 'Branch Location Image', 'lafka-plugin' ); ?></label>
            </th>
            <td>
                <div id="lafka_branch_location_img" style="float: left; margin-right: 10px;"><img
                            src="<?php echo esc_url( $branch_image_src ); ?>" width="60px" height="60px"/></div>
                <div style="line-height: 60px;">
                    <input type="hidden" id="lafka_branch_location_img_id" name="lafka_branch_location_img_id" value="<?php echo esc_attr( $branch_image_id ); ?>"/>
                    <button type="button"
                            class="lafka_branch_location_img_upload_image_button button"><?php echo esc_html__( 'Upload/Add image', 'lafka-plugin' ); ?></button>
                    <button type="button"
                            class="lafka_branch_location_img_remove_image_button button"><?php echo esc_html__( 'Remove image', 'lafka-plugin' ); ?></button>
                </div>
                <div class="clear"></div>
                <p class="description"><?php esc_html_e( 'The image will be shown on the popup for selecting the branch.', 'lafka-plugin' ); ?></p>
            </td>
        </tr>
        <tr class="form-field">
            <th scope="row">
                <label for="lafka_branch_shipping_areas"><?php esc_html_e( 'Shipping Areas', 'lafka-plugin' ); ?></label>
            </th>
            <td>
                <select multiple="multiple" class="wc-enhanced-select" name="lafka_branch_shipping_areas[]" id="lafka_branch_shipping_areas"
                        data-placeholder="<?php esc_attr_e( 'Choose Shipping Areas&hellip;', 'lafka-plugin' ); ?>" aria-label="<?php esc_attr_e( 'Shipping Areas', 'lafka-plugin' ); ?>">
					<?php foreach ( $delivery_areas as $option_key => $option_value ) : ?>
                        <option value="<?php echo esc_attr( $option_key ); ?>" <?php echo wc_selected( $option_key, $branch_shipping_areas ); ?>><?php echo esc_html( $option_value ); ?></option>
					<?php endforeach; ?>
                </select>
                <p class="description"><?php esc_html_e( 'Choose Lafka Shipping Areas covered by this branch.', 'lafka-plugin' ); ?></p>
            </td>
        </tr>
        <tr class="form-field">
            <th scope="row">
                <label for="lafka_branch_distance_restriction"><?php esc_html_e( 'Radius Restriction', 'lafka-plugin' ); ?></label>
            </th>
            <td>
                <input name="lafka_branch_distance_restriction" id="lafka_branch_distance_restriction" type="number" value="<?php esc_attr_e( $distance_restriction ); ?>"/>
                <p class="description"><?php esc_html_e( 'Suitable for radius based delivery restrictions. This option is only used for the initial check (popup) of the delivery availability based on the user address.', 'lafka-plugin' ); ?></p>
            </td>
        </tr>
        <tr class="form-field">
            <th scope="row">
                <label for=" lafka_branch_distance_unit"><?php esc_html_e( 'Distance Unit', 'lafka-plugin' ); ?></label>
            </th>
            <td>
                <select class="select wc-enhanced-select" name="lafka_branch_distance_unit" id="lafka_branch_distance_unit" style="">
                    <option value="metric" <?php selected( $distance_unit, 'metric' ); ?>><?php esc_html_e( 'Metric (km)', 'lafka-plugin' ); ?></option>
                    <option value="imperial"<?php selected( $distance_unit, 'imperial' ); ?>><?php esc_html_e( 'Imperial (miles)', 'lafka-plugin' ); ?></option>
                </select>
            </td>
        </tr>
        <tr class="form-field form-required lafka_branch_address-wrap">
            <th scope="row">
                <label for="lafka_branch_address"><?php esc_html_e( 'Address', 'lafka-plugin' ); ?></label>
            </th>
            <td>
                <input name="lafka_branch_address" id="lafka_branch_address" placeholder="<?php esc_html_e( 'Enter a location', 'lafka-plugin' ); ?>" type="text"
                       value="<?php esc_attr_e( $address ); ?>"/>
                <input name="lafka_branch_address_geocoded" id="lafka_branch_address_geocoded" type="hidden" value="<?php esc_attr_e( $address_geocoded ); ?>"/>
                <p class="description">
					<?php esc_html_e( 'The full address for the branch to calculate distance shipping and apply radius restrictions.', 'lafka-plugin' ); ?>
					<?php esc_html_e( 'Note: Branch Location will be active only if it is properly geocoded.', 'lafka-plugin' ); ?><br>
                    <span class="lafka-branch-address-instructions">
                        <strong><?php esc_html_e( 'Instructions', 'lafka-plugin' ); ?></strong>: <?php esc_html_e( 'Enter an address in the textbox and geocode or click on the map to set the location.', 'lafka-plugin' ); ?>
                    </span>
                </p>
                <div id="lafka_geocode_branch_location_map"></div>
            </td>
        </tr>
		<?php
	}

	public static function edit_branch_location( $term_id ) {
		if ( isset( $_POST['lafka_branch_delivery_time'] ) ) {
			update_term_meta( $term_id, 'lafka_branch_delivery_time', sanitize_text_field( $_POST['lafka_branch_delivery_time'] ) );
		}
		if ( isset( $_POST['lafka_branch_location_img_id'] ) ) {
			update_term_meta( $term_id, 'lafka_branch_location_img_id', sanitize_text_field( $_POST['lafka_branch_location_img_id'] ) );
		}
		if ( isset( $_POST['lafka_branch_address'] ) ) {
			update_term_meta( $term_id, 'lafka_branch_address', sanitize_text_field( $_POST['lafka_branch_address'] ) );
		}
		if ( isset( $_POST['lafka_branch_address_geocoded'] ) ) {
			// Using esc_attr(), because sanitize_text_field() breaks the json string
			update_term_meta( $term_id, 'lafka_branch_address_geocoded', esc_attr( $_POST['lafka_branch_address_geocoded'] ) );
		}
		if ( isset( $_POST['lafka_branch_shipping_areas'] ) ) {
			update_term_meta( $term_id, 'lafka_branch_shipping_areas', sanitize_text_field( json_encode( $_POST['lafka_branch_shipping_areas'] ) ) );
		}
		if ( isset( $_POST['lafka_branch_distance_restriction'] ) ) {
			update_term_meta( $term_id, 'lafka_branch_distance_restriction', sanitize_text_field( $_POST['lafka_branch_distance_restriction'] ) );
		}
		if ( isset( $_POST['lafka_branch_distance_unit'] ) ) {
			update_term_meta( $term_id, 'lafka_branch_distance_unit', sanitize_text_field( $_POST['lafka_branch_distance_unit'] ) );
		}
	}

	public static function add_address_column_to_location_branches( $columns ): array {
		$new_columns = array();
		if ( isset( $columns['cb'] ) ) {
			$new_columns['cb'] = $columns['cb'];
			unset( $columns['cb'] );
		}
		if ( isset( $columns['name'] ) ) {
			$new_columns['name'] = $columns['name'];
			unset( $columns['name'] );
		}
		$new_columns['lafka_branch_address'] = esc_html__( 'Address', 'lafka-plugin' );

		return array_merge( $new_columns, $columns );
	}

	public static function add_address_column_content_to_location_branches( $columns, $column, $id ) {
		$address = get_term_meta( $id, 'lafka_branch_address', true );
		if ( $address ) {
			echo esc_html( $address );
		}
	}

	public static function add_columns_to_orders_list( $columns ): array {
		$columns['lafka_selected_branch'] = esc_html__( 'Branch', 'lafka-plugin' );
		$columns['lafka_order_type']      = esc_html__( 'Order Type', 'lafka-plugin' );

		return $columns;
	}

	public static function add_columns_content_to_orders_list( $column ) {
		global $post;
		if ( $column === 'lafka_selected_branch' ) {
			$branch_id = get_post_meta( $post->ID, 'lafka_selected_branch_id', true );
			$branch    = get_term( $branch_id );
			if ( ! empty( $branch->name ) ) {
				echo '<span>' . esc_html( $branch->name ) . '</span>';
			}
		} elseif ( $column === 'lafka_order_type' ) {
			$order_type = get_post_meta( $post->ID, 'lafka_order_type', true );
			if ( $order_type === 'delivery' ) {
				echo '<span class="lafka-order-type-delivery">' . esc_html__( 'Delivery', 'lafka-plugin' ) . '</span>';
			} elseif ( $order_type === 'pickup' ) {
				echo '<span class="lafka-order-type-pickup">' . esc_html__( 'Pickup', 'lafka-plugin' ) . '</span>';
			}
		}
	}

	public static function add_columns_to_sortable_columns( $columns ): array {
		$columns['lafka_selected_branch'] = 'lafka_selected_branch_id';
		$columns['lafka_order_type']      = 'lafka_order_type';

		return $columns;
	}

	public static function orders_list_define_sort_and_search_queries_for_custom_fields( $query ) {
		if ( function_exists( 'get_current_screen' ) ) {
			$current_screen = get_current_screen();
			if ( is_admin() && ! empty( $current_screen ) && $current_screen->id === 'edit-shop_order' ) {
				$meta_query_args = array();
				$branch_id       = $_GET['branch_location_filter'] ?? '';
				if ( is_numeric( $branch_id ) ) {
					$meta_query_args[] = array(
						'key'   => 'lafka_selected_branch_id',
						'value' => $branch_id
					);
				}

				$order_type = $_GET['order_type_filter'] ?? '';
				if ( $order_type ) {
					$meta_query_args[] = array(
						'key'   => 'lafka_order_type',
						'value' => sanitize_text_field( $order_type )
					);
				}

				$order_by = $query->get( 'orderby' );
				if ( $order_by === 'lafka_checkout_date' ) {
					$meta_query_args[] = array(
						'relation' => 'OR',
						array(
							'lafka_checkout_date_clause'     => array(
								'key'     => 'lafka_checkout_date',
								'compare' => 'EXISTS'
							),
							'lafka_checkout_timeslot_clause' => array(
								'key'     => 'lafka_checkout_timeslot',
								'compare' => 'EXISTS'
							)
						),
						array(
							'lafka_checkout_date_clause'     => array(
								'key'     => 'lafka_checkout_date',
								'compare' => 'NOT EXISTS'
							),
							'lafka_checkout_timeslot_clause' => array(
								'key'     => 'lafka_checkout_timeslot',
								'compare' => 'NOT EXISTS'
							)
						)
					);
					$query->set( 'orderby', array(
						'lafka_checkout_date_clause'     => sanitize_text_field( $_GET['order'] ),
						'lafka_checkout_timeslot_clause' => sanitize_text_field( $_GET['order'] )
					) );
				}

				if ( ! empty( $meta_query_args ) ) {
					$query->set( 'meta_query', $meta_query_args );
				}
			}
		}
	}

	public static function add_fields_to_orders_list_filter( $post_type, $which ) {
		if ( $post_type == 'shop_order' ) {
			$all_branches = Lafka_Shipping_Areas::get_all_legit_branch_locations();
			if ( ! empty( $all_branches ) ) {
				$filtered_branch_id = $_GET['branch_location_filter'] ?? '';
				?>
                <select id="branch_location_filter" name="branch_location_filter">
                    <option value=""><?php esc_html_e( 'All Branches', 'lafka-plugin' ); ?></option>
					<?php foreach ( $all_branches as $id => $name ): ?>
                        <option value="<?php echo esc_attr( $id ); ?>" <?php selected( $id, (int) $filtered_branch_id ); ?> >
							<?php echo esc_html( $name ); ?>
                        </option>
					<?php endforeach; ?>
                </select>
				<?php
			}
			$filtered_order_type = $_GET['order_type_filter'] ?? '';
			?>
            <select id="order_type_filter" name="order_type_filter">
                <option value=""><?php esc_html_e( 'All Order Types', 'lafka-plugin' ); ?></option>
                <option value="delivery" <?php selected( 'delivery', esc_attr( $filtered_order_type ) ); ?> ><?php esc_html_e( 'Delivery', 'lafka-plugin' ); ?></option>
                <option value="pickup" <?php selected( 'pickup', esc_attr( $filtered_order_type ) ); ?> ><?php esc_html_e( 'Pickup', 'lafka-plugin' ); ?></option>
            </select>
			<?php
		}
	}
}

Lafka_Branch_Locations_Admin::init();