<?php
defined( 'ABSPATH' ) || exit;

class Lafka_Branch_Locations {
	public static function init() {
		add_action( 'wp_enqueue_scripts', array( __CLASS__, 'enqueue_scripts' ) );
		add_action( 'wp_footer', array( __CLASS__, 'output_in_footer' ) );

		// Handle branch selection Ajax
		add_action( 'wp_ajax_nopriv_lafka_select_branch', array( __CLASS__, 'select_branch' ) );
		add_action( 'wp_ajax_lafka_select_branch', array( __CLASS__, 'select_branch' ) );

		// Set WC session for not logged-in users
		add_action( 'woocommerce_init', array( __CLASS__, 'create_wc_session_if_needed' ) );

		// Change branch and/or address
		add_action( 'wp_ajax_nopriv_lafka_change_branch', array( __CLASS__, 'change_branch' ) );
		add_action( 'wp_ajax_lafka_change_branch', array( __CLASS__, 'change_branch' ) );

		// Add meta fields to the order
		add_action( 'woocommerce_checkout_update_order_meta', array( __CLASS__, 'checkout_field_update_order_meta_fields' ), 10, 1 );

		// Alter Products meta query to get only the corresponding branch products
		$options_branches = get_option( 'lafka_shipping_areas_branches' );
		if ( ! empty( $options_branches['products_by_branches'] ) ) {
			add_filter( 'woocommerce_product_query_tax_query', array( __CLASS__, 'modify_products_tax_query_to_get_branch_products' ), 10, 2 );
			add_filter( 'woocommerce_subcategory_count_html', '__return_false' );
		}
		// Where to show branch info box (for 'shop' look in the theme)
		if ( isset( $options_branches['show_branches_info_in'] ) && in_array( 'mini_cart', $options_branches['show_branches_info_in'] ) ) {
			add_action( 'woocommerce_before_mini_cart', array( __CLASS__, 'show_change_branch' ) );
		}
		if ( isset( $options_branches['show_branches_info_in'] ) && in_array( 'cart', $options_branches['show_branches_info_in'] ) ) {
			add_action( 'woocommerce_before_cart_totals', array( __CLASS__, 'show_change_branch' ) );
		}
		if ( isset( $options_branches['show_branches_info_in'] ) && in_array( 'checkout', $options_branches['show_branches_info_in'] ) ) {
			add_action( 'woocommerce_checkout_order_review', array( __CLASS__, 'show_change_branch' ), 1 );
		}

		// Pre-populate customer address and save in customer session
		add_filter( 'woocommerce_default_address_fields', array( __CLASS__, 'populate_delivery_address_from_session' ) );
		add_filter( 'default_checkout_billing_state', array( __CLASS__, 'change_default_checkout_state' ) );
		add_filter( 'default_checkout_shipping_state', array( __CLASS__, 'change_default_checkout_state' ) );

		// Update the infobox address the checkout address
		add_action( 'woocommerce_checkout_update_order_review', array( __CLASS__, 'update_lafka_session_address' ) );

		// Disable shipping locations if Pick Up is selected
		add_filter( 'wc_shipping_enabled', array( __CLASS__, 'enable_shipping_only_for_delivery' ) );
	}

	public static function enqueue_scripts() {
		$branch_locations_json_data = self::get_branch_locations_json_data();
		$options_branches           = get_option( 'lafka_shipping_areas_branches' );

		wp_enqueue_script( 'lafka-branch-locations-front', plugins_url( '../assets/js/frontend/lafka-branch-locations-front.min.js', __FILE__ ), array(
			'google-maps',
			'jquery-blockui',
			'wc-country-select'
		), '1.0', true );
		wp_localize_script( 'lafka-branch-locations-front', 'lafka_branch_locations_front', array(
			'ajax_url'                            => admin_url( 'admin-ajax.php' ),
			'is_closable'                         => ( ! empty( $options_branches['closable_popup'] ) && empty( $options_branches['products_by_branches'] ) ),
			'order_type'                          => empty( $options_branches['order_type'] ) ? 'delivery_pickup' : $options_branches['order_type'],
			'has_session_value'                   => ( isset( WC()->session ) && ! empty( WC()->session->get( 'lafka_branch_location' ) ) ),
			'branch_locations_json_data'          => $branch_locations_json_data,
			'please_wait_message'                 => esc_html__( 'Please wait', 'lafka-plugin' ),
			'info_message_select_branch_delivery' => esc_html__( 'Select from branches serving your area', 'lafka-plugin' ),
			'info_message_select_branch_pickup'   => esc_html__( 'Select a branch', 'lafka-plugin' ),
			'error_message_no_address'            => esc_html__( 'Please type your address and select suggestion or click on "Use current location...".', 'lafka-plugin' ),
			'error_message_json_parse'            => esc_html__( 'Something is wrong. Please try again.', 'lafka-plugin' ),
			'error_message_no_suitable_branches'  => esc_html__( 'Sorry, your address cannot be served by any of our branches.', 'lafka-plugin' ),
			'error_message_not_found'             => esc_html__( 'No results found.', 'lafka-plugin' ),
			'error_message_geocoder_failed'       => esc_html__( 'Geocoder failed due to', 'lafka-plugin' ),
			'error_message_precise_address'       => esc_html__( 'Please enter precise address.', 'lafka-plugin' ),
			'error_message_select_branch'         => esc_html__( 'Please select branch to continue.', 'lafka-plugin' ),
		) );
		wp_enqueue_style( 'wp-jquery-ui-dialog' );
	}

	public static function output_in_footer() {
		$options_branches = get_option( 'lafka_shipping_areas_branches' );
		?>
        <div id="lafka_select_branch_modal" class="mfp-hide">
            <form id="lafka_select_branch_form">
                <div class="lafka-branch-order-type">
					<?php if ( in_array( 'delivery', self::get_order_type() ) ): ?>
                        <a href="javascript:" class="lafka-branch-delivery"><?php esc_html_e( 'Delivery', 'lafka-plugin' ); ?></a>
					<?php endif; ?>
					<?php if ( in_array( 'pickup', self::get_order_type() ) ): ?>
                        <a href="javascript:" class="lafka-branch-pickup"><?php esc_html_e( 'Local pickup', 'lafka-plugin' ); ?></a>
					<?php endif; ?>
                </div>
                <div class="lafka-branch-user-address">
                    <label for="lafka_branch_select_user_address"><?php esc_html_e( 'Address', 'lafka-plugin' ); ?>
                        <input type="text" id="lafka_branch_select_user_address" name="lafka_branch_select_user_address"
                               placeholder="<?php esc_html_e( 'Enter a delivery address', 'lafka-plugin' ); ?>"/>
						<?php if ( empty( $options_branches['disable_current_location'] ) ): ?>
                            <a href="javascript:" class="lafka-branch-auto-locate" title="<?php esc_html_e( 'Use current location', 'lafka-plugin' ); ?>">
                                <i class="fa fa-location-arrow"></i>
								<?php esc_html_e( 'or detect my current location', 'lafka-plugin' ); ?>
                            </a>
						<?php endif; ?>
                    </label>
                </div>
				<?php
				$branches              = Lafka_Shipping_Areas::get_all_legit_branch_locations();
				$branch_selection_type = empty( $options_branches['branch_selection_type'] ) ? 'images' : $options_branches['branch_selection_type']
				?>
                <div class="lafka-branch-selection">
					<?php if ( $branch_selection_type === 'images' ): ?>
                        <div class="lafka-branch-select-images">
							<?php if ( empty( $branches ) ): ?>
                                <span class="lafka-branch-select-tip"><?php esc_html_e( 'Sorry, no location available to order for this address.', 'lafka-plugin' ); ?></span>
							<?php else: ?>
                                <span class="lafka-branch-select-tip"></span>
								<?php foreach ( $branches as $id => $name ): ?>
                                    <span class="lafka-branch-select-image  lafka-branch-<?php echo esc_attr( $id ); ?>">
                                    <a href="javascript:" data-branch-id="<?php echo (int) $id; ?>">
                                        <?php
                                        $branch_image_id = get_term_meta( $id, 'lafka_branch_location_img_id', true );
                                        if ( $branch_image_id ) {
	                                        $branch_image_src = wp_get_attachment_thumb_url( $branch_image_id );
                                        } else {
	                                        $branch_image_src = wc_placeholder_img_src();
                                        }
                                        ?>
                                        <img src="<?php echo esc_url( $branch_image_src ); ?>" alt="<?php echo esc_attr( $name ); ?>"/>
                                        <span class="lafka-branch-select-name"><?php echo esc_html( $name ); ?></span>
                                    </a>
                                </span>
								<?php endforeach; ?>
							<?php endif; ?>
                            <input type="hidden" name="lafka_selected_branch_id" id="lafka_selected_branch_id"/>
                        </div>
					<?php elseif ( $branch_selection_type === 'select' ): ?>
                        <div class="lafka-branch-select-dropdown">
                            <label class="lafka_branch_select_label" for="lafka_branch_select"></label>
                            <select id="lafka_branch_select" name="lafka_branch_select">
                                <option value="" disabled selected><?php esc_html_e( 'Select Branch', 'lafka-plugin' ); ?> ...</option>
								<?php foreach ( $branches as $id => $name ): ?>
                                    <option value="<?php echo esc_attr( $id ); ?>"><?php echo esc_html( $name ) ?></option>
								<?php endforeach; ?>
                            </select>
                        </div>
					<?php endif; ?>
                </div>
                <div class="lafka-branch-select-message"></div>
                <input type="hidden" name="lafka_branch_order_type" id="lafka_branch_order_type"/>
                <input type="hidden" name="lafka_user_country" id="lafka_user_country"/>
                <input type="hidden" name="lafka_user_address_1" id="lafka_user_address_1"/>
                <input type="hidden" name="lafka_user_city" id="lafka_user_city"/>
                <input type="hidden" name="lafka_user_state" id="lafka_user_state"/>
                <input type="hidden" name="lafka_user_postcode" id="lafka_user_postcode"/>
                <input type="hidden" name="lafka_user_geocoded_location" id="lafka_user_geocoded_location"/>
				<?php wp_nonce_field( 'lafka_select_branch' ); ?>
                <a class="lafka-branch-select-submit button" href="javascript:"><?php esc_html_e( 'Start Order', 'lafka-plugin' ); ?></a>
            </form>
        </div>
		<?php
	}

	public static function select_branch() {
		check_ajax_referer( 'lafka_select_branch' );

		$fields_string = urldecode( $_POST['fields'] );
		parse_str( $fields_string, $fields );

		$selected_branch_id = null;
		if ( ! empty( $fields['lafka_branch_select'] ) ) {
			$selected_branch_id = (int) $fields['lafka_branch_select'];
		} elseif ( ! empty( $fields['lafka_selected_branch_id'] ) ) {
			$selected_branch_id = (int) $fields['lafka_selected_branch_id'];
		}

		if ( empty( $selected_branch_id ) ) {
			wp_send_json_error( new WP_Error( 'empty_request', esc_html__( 'Please select branch to continue.', 'lafka-plugin' ) ) );
		}

		if ( empty( $fields['lafka_branch_order_type'] ) ) {
			wp_send_json_error( new WP_Error( 'empty_request', esc_html__( 'Please select order type.', 'lafka-plugin' ) ) );
		}

		if ( $fields['lafka_branch_order_type'] === 'delivery' && ( empty( $fields['lafka_branch_select_user_address'] ) || empty( $fields['lafka_user_country'] ) ) ) {
			wp_send_json_error( new WP_Error( 'empty_request', esc_html__( 'Please type your address and select suggested address or click on "Use current location".', 'lafka-plugin' ) ) );
		}

		$branch_location = get_term( $selected_branch_id );

		if ( empty( $branch_location ) || is_wp_error( $branch_location ) ) {
			wp_send_json_error( new WP_Error( 'no_branch', esc_html__( 'Something is wrong. No such branch location.', 'lafka-plugin' ) ) );
		}

		// If we are here - all is good
		$lafka_branch_location_session = array(
			'branch_id'  => $selected_branch_id,
			'order_type' => $fields['lafka_branch_order_type'],
			'country'    => $fields['lafka_user_country'],
			'address_1'  => $fields['lafka_user_address_1'],
			'city'       => $fields['lafka_user_city'],
			'state'      => self::get_processed_state_code_from_google_state( $fields['lafka_user_state'], $fields['lafka_user_country'] ),
			'postcode'   => $fields['lafka_user_postcode'],
		);;

		$full_address                                  = self::build_full_address_from_components( $lafka_branch_location_session );
		$lafka_branch_location_session['full_address'] = $full_address;

		WC()->session->set( 'lafka_branch_location', $lafka_branch_location_session );

		wp_send_json_success();
	}

	public static function create_wc_session_if_needed() {
		if ( is_user_logged_in() || is_admin() ) {
			return;
		}

		if ( isset( WC()->session ) && ! WC()->session->has_session() ) {
			WC()->session->set_customer_session_cookie( true );
		}
	}

	public static function show_change_branch() {
		$branch_location_session = WC()->session->get( 'lafka_branch_location' );

		if ( ! empty( $branch_location_session ) ) {
			$branch = get_term( $branch_location_session['branch_id'], 'lafka_branch_location' );
			if ( is_wp_error( $branch ) || empty( $branch ) ) {
				$branch_name = '';
			} else {
				$branch_name = $branch->name;
			}
			$delivery_time   = get_term_meta( $branch_location_session['branch_id'], 'lafka_branch_delivery_time', true );
			$order_type_text = esc_html__( 'Delivery', 'lafka-plugin' );
			$class           = 'lafka-delivery-info';
			if ( $branch_location_session['order_type'] === 'pickup' ) {
				$order_type_text = esc_html__( 'Pickup', 'lafka-plugin' );
				$class           = 'lafka-pickup-info';
			}
			?>
            <div class="lafka-change-branch <?php echo sanitize_html_class( $class ); ?>">
				<?php if ( ! empty( $delivery_time ) ): ?>
                    <span class="lafka-estimated-time"><?php echo esc_html( $delivery_time ); ?></span>
				<?php endif; ?>
                <span><strong><?php echo esc_html( $order_type_text ); ?> <?php esc_html_e( 'from', 'lafka-plugin' ); ?>:</strong> <?php echo esc_html( $branch_name ); ?></span>
                <span>
                    <?php if ( $branch_location_session['order_type'] === 'delivery' ): ?>
                        <strong><?php esc_html_e( 'To', 'lafka-plugin' ); ?>:</strong>
                        <span class="lafka-change-branch-full-address"><?php echo esc_html( $branch_location_session['full_address'] ); ?></span>
                    <?php endif; ?>
                    <a href="javascript:" class="lafka-change-branch-button"
                       data-nonce="<?php echo esc_attr( wp_create_nonce( 'lafka_change_branch' ) ); ?>"><?php esc_html_e( 'Change', 'lafka-plugin' ); ?></a>
                </span>
            </div>
			<?php
		} else if ( ! empty( Lafka_Shipping_Areas::get_all_legit_branch_locations() ) ) {
			?>
            <div class="lafka-change-branch">
                <a href="javascript:" class="lafka-change-branch-button-select"
                   data-nonce="<?php echo esc_attr( wp_create_nonce( 'lafka_change_branch' ) ); ?>"><?php esc_html_e( 'Select Location', 'lafka-plugin' ); ?></a>
            </div>
			<?php
		}
	}

	public static function change_branch() {
		check_ajax_referer( 'lafka_change_branch' );

		if ( ! empty( WC()->session ) ) {
			WC()->session->set( 'lafka_branch_location', '' );
			wp_send_json_success();
		}

		wp_send_json_error( new WP_Error( 'error', __( 'Something is wrong. No session.', 'lafka-plugin' ) ) );
	}

	public static function modify_products_tax_query_to_get_branch_products( $tax_query, $wc_query ) {
		$branch_location_session = WC()->session->get( 'lafka_branch_location' );
		if ( ! empty( $branch_location_session['branch_id'] ) && is_numeric( $branch_location_session['branch_id'] ) ) {
			$branch_products_tax_args = array(
				'taxonomy' => 'lafka_branch_location',
				'field'    => 'term_taxonomy_id',
				'terms'    => $branch_location_session['branch_id']
			);
			$tax_query[]              = $branch_products_tax_args;
		}

		return $tax_query;
	}

	public static function populate_delivery_address_from_session( $address_fields ): array {
		$session_data = WC()->session->get( 'lafka_branch_location' );

		if ( ! empty( $session_data ) ) {
			global $woocommerce;

			// Important: Do not remove. Saves address in customer session - ensures shipping methods are properly processed on first load on checkout
			/** @var WC_Customer $customer */
			$customer = $woocommerce->customer;
			$customer->set_billing_country( $session_data['country'] );
			$customer->set_shipping_country( $session_data['country'] );
			$customer->set_billing_address_1( $session_data['address_1'] );
			$customer->set_shipping_address_1( $session_data['address_1'] );
			$customer->set_billing_city( $session_data['city'] );
			$customer->set_shipping_city( $session_data['city'] );
			$customer->set_billing_state( $session_data['state'] );
			$customer->set_shipping_state( $session_data['state'] );
			$customer->set_billing_postcode( $session_data['postcode'] );
			$customer->set_shipping_postcode( $session_data['postcode'] );

			$customer->get_data_store()->save_to_session( $customer );

			$address_fields['country']['default']   = sanitize_text_field( $session_data['country'] );
			$address_fields['address_1']['default'] = sanitize_text_field( $session_data['address_1'] );
			$address_fields['city']['default']      = sanitize_text_field( $session_data['city'] );
			$address_fields['state']['default']     = sanitize_text_field( $session_data['state'] );
			$address_fields['postcode']['default']  = sanitize_text_field( $session_data['postcode'] );
		}

		return $address_fields;
	}

	private static function build_full_address_from_components( $address_raw_components ): string {
		$address_components = array();

		if ( $address_raw_components['address_1'] ) {
			$address_components[] = $address_raw_components['address_1'];
		}
		if ( ! empty( $address_raw_components['address_2'] ) ) {
			$address_components[] = $address_raw_components['address_2'];
		}
		if ( $address_raw_components['postcode'] ) {
			$address_components[] = $address_raw_components['postcode'];
		}
		if ( $address_raw_components['city'] ) {
			$address_components[] = $address_raw_components['city'];
		}
		if ( $address_raw_components['state'] && $address_raw_components['country'] ) {
			$all_states           = WC()->countries->get_states( $address_raw_components['country'] );
			$address_components[] = $all_states[ $address_raw_components['state'] ] ?? '';
		}
		if ( $address_raw_components['country'] ) {
			$all_countries        = WC()->countries->get_countries();
			$address_components[] = $all_countries[ $address_raw_components['country'] ] ?? '';
		}

		return implode( ', ', $address_components );
	}

	public static function change_default_checkout_state(): string {
		$session_data = WC()->session->get( 'lafka_branch_location' );
		$state        = $session_data['state'] ?? '';

		return sanitize_text_field( $state );
	}

	public static function update_lafka_session_address( $post_data ) {
		$lafka_branch_location_session = WC()->session->get( 'lafka_branch_location' );

		if ( ! empty( $lafka_branch_location_session ) ) {
			parse_str( $post_data, $post_data_array );

			if ( empty( $post_data_array['ship_to_different_address'] ) ) {
				$lafka_branch_location_session['country'] = isset( $post_data_array['billing_country'] ) ? wc_clean( $post_data_array['billing_country'] ) : '';
			} else {
				$lafka_branch_location_session['country'] = isset( $post_data_array['shipping_country'] ) ? wc_clean( $post_data_array['shipping_country'] ) : '';
			}

			if ( empty( $post_data_array['ship_to_different_address'] ) ) {
				$lafka_branch_location_session['address_1'] = isset( $post_data_array['billing_address_1'] ) ? wc_clean( $post_data_array['billing_address_1'] ) : '';
			} else {
				$lafka_branch_location_session['address_1'] = isset( $post_data_array['shipping_address_1'] ) ? wc_clean( $post_data_array['shipping_address_1'] ) : '';
			}

			if ( empty( $post_data_array['ship_to_different_address'] ) ) {
				$lafka_branch_location_session['address_2'] = isset( $post_data_array['billing_address_2'] ) ? wc_clean( $post_data_array['billing_address_2'] ) : '';
			} else {
				$lafka_branch_location_session['address_2'] = isset( $post_data_array['shipping_address_2'] ) ? wc_clean( $post_data_array['shipping_address_2'] ) : '';
			}

			if ( empty( $post_data_array['ship_to_different_address'] ) ) {
				$lafka_branch_location_session['city'] = isset( $post_data_array['billing_city'] ) ? wc_clean( $post_data_array['billing_city'] ) : '';
			} else {
				$lafka_branch_location_session['city'] = isset( $post_data_array['shipping_city'] ) ? wc_clean( $post_data_array['shipping_city'] ) : '';
			}

			if ( empty( $post_data_array['ship_to_different_address'] ) ) {
				$lafka_branch_location_session['state'] = isset( $post_data_array['billing_state'] ) ? wc_clean( $post_data_array['billing_state'] ) : '';
			} else {
				$lafka_branch_location_session['state'] = isset( $post_data_array['shipping_state'] ) ? wc_clean( $post_data_array['shipping_state'] ) : '';
			}

			if ( empty( $post_data_array['ship_to_different_address'] ) ) {
				$lafka_branch_location_session['postcode'] = isset( $post_data_array['billing_postcode'] ) ? wc_clean( $post_data_array['billing_postcode'] ) : '';
			} else {
				$lafka_branch_location_session['postcode'] = isset( $post_data_array['shipping_postcode'] ) ? wc_clean( $post_data_array['shipping_postcode'] ) : '';
			}

			$lafka_branch_location_session['full_address'] = self::build_full_address_from_components( $lafka_branch_location_session );

			WC()->session->set( 'lafka_branch_location', $lafka_branch_location_session );
		}
	}

	public static function enable_shipping_only_for_delivery(): bool {
		if ( isset( WC()->session ) ) {
			$branch_location_session = WC()->session->get( 'lafka_branch_location' );
			if ( ! empty( $branch_location_session['order_type'] ) && $branch_location_session['order_type'] === 'pickup' ) {
				return false;
			}
		}

		return true;
	}

	public static function get_order_type(): array {
		$branches_options = get_option( 'lafka_shipping_areas_branches' );
		$order_type       = empty( $branches_options['order_type'] ) ? 'delivery_pickup' : $branches_options['order_type'];

		$to_return = array();
		switch ( $order_type ) {
			case 'delivery_pickup':
				$to_return[] = 'delivery';
				$to_return[] = 'pickup';
				break;
			case 'delivery':
				$to_return[] = 'delivery';
				break;
			case'pickup':
				$to_return[] = 'pickup';
				break;
		}

		return $to_return;
	}

	public static function checkout_field_update_order_meta_fields( $order_id ) {
		if ( isset( WC()->session ) ) {
			$branch_location_session = WC()->session->get( 'lafka_branch_location' );
			if ( ! empty( $branch_location_session['branch_id'] ) ) {
				update_post_meta( $order_id, 'lafka_selected_branch_id', sanitize_text_field( $branch_location_session['branch_id'] ) );
			}
			if ( ! empty( $branch_location_session['order_type'] ) ) {
				update_post_meta( $order_id, 'lafka_order_type', sanitize_text_field( $branch_location_session['order_type'] ) );
			}
		}
	}

	private static function get_branch_locations_json_data() {
		$locations_rich_data = array();

		$branch_locations = Lafka_Shipping_Areas::get_all_legit_branch_locations();
		foreach ( $branch_locations as $location_id => $location_name ) {
			$location_meta = get_term_meta( $location_id );
			if ( is_array( $location_meta ) ) {
				$shipping_areas = array();
				if ( ! empty( $location_meta['lafka_branch_shipping_areas'][0] ) ) {
					foreach ( json_decode( $location_meta['lafka_branch_shipping_areas'][0] ) as $shipping_area_id ) {
						$shipping_areas[] = array(
							'id'                       => $shipping_area_id,
							'area_polygon_coordinates' => get_post_meta( $shipping_area_id, '_lafka_shipping_area_polygon_coordinates', true )
						);
					}
				}
				$locations_rich_data[] = array(
					'id'                      => $location_id,
					'distance_restriction'    => $location_meta['lafka_branch_distance_restriction'][0] ?? '',
					'distance_unit'           => $location_meta['lafka_branch_distance_unit'][0] ?? '',
					'branch_address_geocoded' => $location_meta['lafka_branch_address_geocoded'][0] ?? '',
					'shipping_areas'          => $shipping_areas,
				);
			}
		}

		return json_encode( $locations_rich_data );
	}

	private static function get_processed_state_code_from_google_state( $state, $country ) {
		$known_google_geocoded_incompatible_states = array(
			'Sofia City Province' => 'Sofia-Grad'
		);
		$wc_state_code                             = '';

		if ( ! empty( $country ) && ! empty( WC()->countries ) ) {
			$wc_country_states = WC()->countries->get_states( $country );
			if ( ! empty( $state ) ) {
				if ( empty( $wc_country_states[ $state ] ) ) {
					$processed_state = $known_google_geocoded_incompatible_states[ $state ] ?? $state;
					$state_index     = array_search( $processed_state, $wc_country_states );
					if ( $state_index !== false ) {
						$wc_state_code = $state_index;
					}
				} else {
					$wc_state_code = $state;
				}
			}
		}

		return $wc_state_code;
	}
}

Lafka_Branch_Locations::init();